==> humhub-1.3.3.tar.gz: humhub-1.3.3/protected/humhub/modules/directory/messages/fi/base.php <==
<?php
return array (
  '<b>Nobody wrote something yet.</b><br>Make the beginning and post something...' => '<b>Kukaan ei ole kirjoittanut mitään.</b><br> Kirjoita jotain ...',
  '<b>There are no profile posts yet!</b>' => '<b>Täällä ei ole vielä mitään!</b>',
  '<strong>Directory</strong> menu' => '<strong>Hakemisto</strong>',
  '<strong>Group</strong> members - {group}' => '<strong>Ryhmän</strong> jäsenet - {group}',
  '<strong>Group</strong> stats' => '<strong>Ryhmä</strong> tilastot',
  '<strong>Member</strong> Group Directory' => '<strong>Ryhmän</strong> Jädenten Hakemisto',
  '<strong>Member</strong> directory' => '<strong>Käyttäjä</strong> hakemisto',
  '<strong>Member</strong> stats' => '<strong>Käyttäjä</strong> tilastot',
  '<strong>New</strong> people' => '<strong>Uudet</strong> ihmiset',
  '<strong>New</strong> spaces' => '<strong>Uudet</strong> sivut',
  '<strong>Space</strong> directory' => '<strong>Sivujen</strong> hakemisto',
  '<strong>Space</strong> stats' => '<strong>Sivujen</strong> tilastot',
  'Access directory' => 'Pääsy hakemistoon',
  'Average members' => 'Keskimääräärin jäseniä',
  'Can access the directory section.' => 'Pääsy hakemisto osioon.',
  'Directory' => 'Hakemisto',
  'Follows somebody' => 'Seuraa jotakuta',
  'Groups' => 'Ryhmät',
  'Members' => 'Jäsenet',
  'Most members' => 'Eniten jäseniä',
  'No members found!' => 'Käyttäjää ei lyötynyt',
  'No spaces found!' => 'Sivuja ei löytynyt!',
  'Online right now' => 'Paikkalla tällä hetkellä',
  'Private spaces' => 'Yksityiset sivut',
  'Search' => 'Hae',
  'See all' => 'Katso kaikki',
  'Send invite' => 'Lähetä kutsu',
  'Spaces' => 'Sivut',
  'This group has no members yet.' => 'Tässä ryhmässä ei ole vielä jäseniä',
  'Top Group' => 'Paras Ryhmä',
  'Total groups' => 'Ryhmiä yhteensä',
  'Total spaces' => 'Sivuja yhteensä',
  'Total users' => 'Käyttäjiä yhteensä',
  'User profile posts' => 'Käyttäjien viestejä',
  'You are a member of this space' => 'Sinä olet jo osalisena tällä sivulla',
  'search for members' => 'Hae käyttäjiä',
  'search for spaces' => 'Hae sivuja',
  'show all members' => 'Näytä kaikki käyttäjät',
);

==> humhub-1.3.10.tar.gz: humhub-1.3.10/protected/humhub/modules/directory/messages/fi/base.php <==
<?php
return array (
  '<b>Nobody wrote something yet.</b><br>Make the beginning and post something...' => '<b>Kukaan ei ole kirjoittanut mitään.</b><br /> Kirjoita jotain ...',
  '<b>There are no profile posts yet!</b>' => '<b>Täällä ei ole vielä mitään!</b>',
  '<strong>Directory</strong> menu' => '<strong>Hakemisto</strong>',
  '<strong>Group</strong> members - {group}' => '<strong>Ryhmän</strong> jäsenet - {group}',
  '<strong>Group</strong> stats' => '<strong>Ryhmä</strong> tilastot',
  '<strong>Member</strong> Group Directory' => '<strong>Ryhmän</strong> Jädenten Hakemisto',
  '<strong>Member</strong> directory' => '<strong>Käyttäjä</strong> hakemisto',
  '<strong>Member</strong> stats' => '<strong>Käyttäjä</strong> tilastot',
  '<strong>New</strong> people' => '<strong>Uudet</strong> ihmiset',
  '<strong>New</strong> spaces' => '<strong>Uusimmat</strong> sivut',
  '<strong>Space</strong> directory' => '<strong>Kaikki</strong> sivut',
  '<strong>Space</strong> stats' => '<strong>Sivujen</strong> tilastot',
  'Access directory' => 'Pääsy hakemistoon',
  'Average members' => 'Keskimääräärin jäseniä',
  'Can access the directory section.' => 'Pääsy hakemisto osioon.',
  'Directory' => 'Hakemisto',
  'Follows somebody' => 'Seuraa jotakuta',
  'Groups' => 'Ryhmät',
  'Members' => 'Jäsenet',
  'Most members' => 'Eniten jäseniä',
  'No members found!' => 'Käyttäjää ei lyötynyt',
  'No spaces found!' => 'Sivuja ei löytynyt!',
  'Online right now' => 'Paikkalla tällä hetkellä',
  'Private spaces' => 'Yksityiset sivut',
  'Search' => 'Hae',
  'See all' => 'Katso kaikki',
  'Send invite' => 'Lähetä kutsu',
  'Spaces' => 'Sivut',
  'This group has no members yet.' => 'Tässä ryhmässä ei ole vielä jäseniä',
  'Top Group' => 'Paras Ryhmä',
  'Total groups' => 'Ryhmiä yhteensä',
  'Total spaces' => 'Sivuja yhteensä',
  'Total users' => 'Käyttäjiä yhteensä',
  'User profile posts' => 'Käyttäjien viestejä',
  'You are a member of this space' => 'Sinä olet jo osalisena tällä sivulla',
  'search for members' => 'Hae käyttäjiä',
  'search for spaces' => 'Hae sivuja',
  'show all members' => 'Näytä kaikki käyttäjät',
);
